@@ -3,9 +3,9 @@
 ### Part of the R package visova
 
 
-visovaChart <- function(type, checked.data, groups, groupCol, order, options, chartid, package, formats = NULL){
+visovaChart <- function(type, checked.data, groups, group_names, colors, groupCol, order, options, chartid, package, formats = NULL){
   
-  Chart = visova(type=type, checked.data, groups, groupCol, order, options=options, chartid=chartid, package, formats=formats)
+  Chart = visova(type=type, checked.data, groups, group_names, colors, groupCol, order, options=options, chartid=chartid, package, formats=formats)
   chartid <- Chart$chartid
   htmlChart <- Chart$chart
   
@@ -17,7 +17,6 @@ visovaChart <- function(type, checked.data, groups, groupCol, order, options, ch
          chartid=Chart$chartid,
          html=list(header=htmlScaffold[["htmlHeader"]],
                    chart=unlist(htmlChart),
-                   caption=htmlScaffold[["htmlCaption"]],
                    footer=htmlScaffold[["htmlFooter"]])),
     class=c("visova", "list")
   )
@@ -25,18 +24,57 @@ visovaChart <- function(type, checked.data, groups, groupCol, order, options, ch
   return(output)
 }
 
+
 stderr <- function(x) ifelse( length(x)>1, sd(x)/sqrt(length(x)), 0 )
 
-visova <- function(type="", data, groups, groupCol, order,  options, chartid, package, formats=NULL){
+
+visova <- function(type="", data, groups, group_names, colors, groupCol, order,  options, chartid, package, formats=NULL){
 
   group_types = unique(groups)
   group_types = sort(as.vector(as.matrix(group_types)))
+    
   group_types2 = group_types
+    
+  group_amounts = table(groups)
+  group_amounts = as.vector(as.matrix(group_amounts))
+  group_amounts = paste(group_amounts,',', collapse='')
+  group_amounts = paste('[',substr(group_amounts, 1, nchar(group_amounts)-1),']')
+    
   groups = paste(groups,',', collapse='')
   groups = paste('[',substr(groups, 1, nchar(groups)-1),']')
+  
   group_types = paste(group_types,',', collapse='')
   group_types = paste('[',substr(group_types, 1, nchar(group_types)-1),']')
+  
+  tmp = '['
+    for(index in 1:length(group_names)){
+        tmp = paste( tmp,'"', group_names[index],'"')
+        if(index != length(group_names)){
+                tmp = paste( tmp, ',')
+        }else{
+                tmp = paste( tmp, ']')
+        }
+        
+    }
+  group_names = tmp
+  
+  tmp2 = '['
+    for(index in 1:length(colors)){
+        tmp2 = paste( tmp2,'"', colors[index],'"')
+        if(index != length(colors)){
+            tmp2 = paste( tmp2, ',')
+        }else{
+            tmp2 = paste( tmp2, ']')
+        }
+        
+    }
+  colors = tmp2
+    
+    
+    
   all_stderr = vector()
+
+     
 #  ndata = as.matrix(data[1:(dim(data)[1]-length(group_types)),])
   
   for(col in 1:(dim(data)[2]-1)){
@@ -115,10 +153,47 @@ var x_coords = new Array();
 var y_coords = new Array();
 var line_nu = 0; 
 var group_nu = 0;
-var colors = ["#2ABDFF","#FA4900","#8AFF00","#B652DB","#F47D24","#4265E9"];
-var alpha_colors = ["#C2ECFF","#FABDA2","#D3FFA1","#CA9ADB","#F5C098","#9EAEE8"];
-	
 
+//DEBUG ME!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+//dodger_blue, red, green, purple, orange, blue
+//var colors = ["#2ABDFF","#FA4900","#8AFF00","#B652DB","#F47D24","#4265E9"];
+//var alpha_colors = ["#C2ECFF","#FABDA2","#D3FFA1","#CA9ADB","#F5C098","#9EAEE8"];
+
+    
+var ncolors = {}
+ncolors[" turquoise "] = "rgb(0,206,209)";
+ncolors[" red "] = "rgb(255,0,0)";
+ncolors[" lime "] = "rgb(0,255,0)";
+ncolors[" purple "] = "rgb(128,0,128)";
+ncolors[" orange "] = "rgb(255,110,0)";
+ncolors[" blue "] = "rgb(0,0,255)";
+ncolors[" yellow "] = "rgb(255,255,0)";
+ncolors[" magenta "] = "rgb(255,0,255)";
+ncolors[" gray "] = "rgb(128,128,128)";
+ncolors[" olive "] = "rgb(128,128,0)";
+ncolors[" green "] = "rgb(0,140,0)";
+ncolors[" teal "] = "rgb(0,128,128)";
+ncolors[" navy "] = "rgb(0,0,128)";
+    
+var nalpha_colors = {}
+    nalpha_colors[" turquoise "] = "rgba(175,238,238,0.4)";
+    nalpha_colors[" red "] = "rgba(250,128,114,0.3)";
+    nalpha_colors[" lime "] = "rgba(152,251,152,0.3)";
+    nalpha_colors[" purple "] = "rgba(186,85,211,0.3)";
+    nalpha_colors[" orange "] = "rgba(255,165,0,0.4)";
+    nalpha_colors[" blue "] = "rgba(123,104,238,0.4)";
+    nalpha_colors[" yellow "] = "rgba(255,255,224,0.6)";
+    nalpha_colors[" magenta "] = "rgba(238,130,238,0.3)";
+    nalpha_colors[" gray "] = "rgba(211,211,211,0.5)";
+    nalpha_colors[" olive "] = "rgba(189,183,107,0.5)";
+    nalpha_colors[" green "] = "rgba(144,238,144,0.5)";
+    nalpha_colors[" teal "] = "rgba(0,128,128,0.1)";
+    nalpha_colors[" navy "] = "rgba(106,90,205,0.2)";
+
+    var colors = [];
+    var alpha_colors = [];
+    
+    
 // Class constructor. Parameter container is a DOM elementon the client that
 // that will contain the visualization.
 vizObj.ParallelC = function(container) {
@@ -131,8 +206,8 @@ function drawAxes(ctx,data,canvasWidth,canvasHeight) {
 	{
 		ctx.strokeStyle = "#BDBDBD";
 		ctx.beginPath();
-		ctx.moveTo(col,30);
-		ctx.lineTo(col,canvasHeight - 30);	
+		ctx.moveTo(col,130);
+		ctx.lineTo(col,canvasHeight - 130);
 		ctx.closePath();
 		ctx.stroke();
 		l_n++;
@@ -149,8 +224,12 @@ function setMaxMin(ctx,data,canvasWidth,canvasHeight) {
 
 		if (data.getColumnType(col) == "number")
 		{
+            
 			colMax = data.getColumnRange(col).max;
 			colMin = data.getColumnRange(col).min;
+            
+            colMax = Math.round(colMax*100)/100;
+            colMin = Math.round(colMin*100)/100;
 		}
 		else
 		{
@@ -167,29 +246,29 @@ function setMaxMin(ctx,data,canvasWidth,canvasHeight) {
 			ctx.StrokeStyle = "#6E6E6E";
 
 			ctx.beginPath();
-			ctx.moveTo(x-10,50);
-			ctx.lineTo(x,50);	
+			ctx.moveTo(x-10,150);
+			ctx.lineTo(x,150);
 			ctx.closePath();
 			ctx.stroke();
 			
 			try
 			{
-				ctx.font = "10px Verdana";
+				ctx.font = "7px Verdana";
 				if (data.getColumnType(col) == "number")
 				{
-					ctx.fillText(colMax,x,50);
+					ctx.fillText(colMax,x,150);
 				}
 				else
 				{
 					//ctx.fillText(data.getDistinctValues(col)[data.getDistinctValues(col).length-1],x,50);
-					ctx.fillText(data.getDistinctValues(col)[colMax],x,50);
+					ctx.fillText(data.getDistinctValues(col)[colMax],x,150);
 				}
 			}
 			catch(e)
 			{
-				ctx.mozTextStyle = "10px Verdana";
+				ctx.mozTextStyle = "7px Verdana";
 				ctx.fillStyle = "black";
-				ctx.translate(x,50);
+				ctx.translate(x,150);
 				if (data.getColumnType(col) == "number")
 				{
 					ctx.mozDrawText(colMax);
@@ -199,36 +278,36 @@ function setMaxMin(ctx,data,canvasWidth,canvasHeight) {
 					//ctx.mozDrawText(data.getDistinctValues(col)[data.getDistinctValues(col).length-1]);
 					ctx.mozDrawText(data.getDistinctValues(col)[colMax]);
 				}
-				ctx.translate(-x,-50);
+				ctx.translate(-x,-150);
 			}
 			
 			if (colMin != -1 && (colMax != colMin))
 			{
 			//label for max
 			ctx.beginPath();
-			ctx.moveTo(x-10,canvasHeight-50);
-			ctx.lineTo(x,canvasHeight-50);	
+			ctx.moveTo(x-10,canvasHeight-150);
+			ctx.lineTo(x,canvasHeight-150);
 			ctx.closePath();
 			ctx.stroke();
 			
 			try
 			{
-				ctx.font = "10px Verdana";
+				ctx.font = "7px Verdana";
 				if (data.getColumnType(col) == "number")
 				{
-					ctx.fillText(colMin,x,canvasHeight-45);
+					ctx.fillText(colMin,x,canvasHeight-145);
 				}
 				else
 				{
 					
-					ctx.fillText(data.getDistinctValues(col)[0],x,canvasHeight-45);	
+					ctx.fillText(data.getDistinctValues(col)[0],x,canvasHeight-145);
 				}
 			}
 			catch(e)
 			{
-				ctx.mozTextStyle = "10px Verdana";
+				ctx.mozTextStyle = "7px Verdana";
 				ctx.fillStyle = "black";
-				ctx.translate(x,canvasHeight-45);
+				ctx.translate(x,canvasHeight-145);
 				if (data.getColumnType(col) == "number")
 				{
 					ctx.mozDrawText(colMin);
@@ -243,11 +322,11 @@ function setMaxMin(ctx,data,canvasWidth,canvasHeight) {
 			}
 			if (data.getColumnType(col) != "number")
 			{
-				var y = 50;
+				var y = 150;
 				for (var i = 1; i < (data.getDistinctValues(col).length - 1) ; i++)
 				{
 					
-					y = y + (((canvasHeight-100)/(data.getDistinctValues(col).length-1)));
+					y = y + (((canvasHeight-300)/(data.getDistinctValues(col).length-1)));
 					ctx.StrokeStyle = "#6E6E6E";
 					ctx.beginPath();
 					ctx.moveTo(x-10,y);
@@ -257,7 +336,7 @@ function setMaxMin(ctx,data,canvasWidth,canvasHeight) {
 					
 					try
 					{
-						ctx.font = "10px Verdana";
+						ctx.font = "7px Verdana";
 						if (data.getColumnType(col) == "number")
 						{
 							ctx.fillText(colMax,x,y);
@@ -269,7 +348,7 @@ function setMaxMin(ctx,data,canvasWidth,canvasHeight) {
 					}
 					catch(e)
 					{
-						ctx.mozTextStyle = "10px Verdana";
+						ctx.mozTextStyle = "7px Verdana";
 						ctx.fillStyle = "black";
 						ctx.translate(x,y);
 						if (data.getColumnType(col) == "number")
@@ -320,11 +399,56 @@ function plotGraph(ctx,data,options,canvasHeight,canvasWidth)
 
 	var groups = %s;
 	var group_types = %s;
+    var group_names = %s;
+    var group_amounts = %s;
 	var all_stderr = %s;
+    var newcolors = %s;
 	index2 = 0;
 	group_nu = group_types.length;
 
 	
+    if(newcolors.length == 0 || newcolors.length < group_nu){
+    
+        colors = ["rgb(0,206,209)",//Turquoise
+                      "rgb(255,0,0)",//Red
+                      "rgb(0,255,0)",//Lime
+                      "rgb(128,0,128)",//Purple
+                      "rgb(255,140,0)",//Orange
+                      "rgb(0,0,255)",//Blue
+                      "rgb(255,255,0)",//Yellow
+                      "rgb(255,0,255)",//Magenta
+                      "rgb(128,128,128)",//Gray
+                      "rgb(128,128,0)",//Olive
+                      "rgb(0,128,0)",//Green
+                      "rgb(0,128,128)",//Teal
+                      "rgb(0,0,128)"//Navy
+                      ];
+        
+        alpha_colors = ["rgba(0,206,209,0.2)",//Turquoise
+                            "rgba(255,0,0,0.2)",//Red
+                            "rgba(0,255,0,0.2)",//Lime
+                            "rgba(128,0,128,0.2)",//Purple
+                            "rgba(255,140,0,0.2)",//Orange
+                            "rgba(0,0,255,0.2)",//Blue
+                            "rgba(255,255,0,0.2)",//Yellow
+                            "rgba(255,0,255,0.2)",//Magenta
+                            "rgba(128,128,128,0.2)",//Gray
+                            "rgba(128,128,0,0.2)",//Olive
+                            "rgba(0,128,0,0.2)",//Green
+                            "rgba(0,128,128,0.2)",//Teal
+                            "rgba(0,0,128,0.2)"//Navy
+                            ];
+
+    }else{
+    
+    for(var index=0; index < newcolors.length; index++){
+    
+        colors.splice(index, 0, ncolors[newcolors[index]]);
+        alpha_colors.splice(index, 0 ,  nalpha_colors[newcolors[index]]);
+    }
+    
+    }
+    
 	for (var row2 = 0; row2 < data.getNumberOfRows(); row2++) 
 	{
 		if(row2 < (data.getNumberOfRows() - group_types.length)){
@@ -337,10 +461,10 @@ function plotGraph(ctx,data,options,canvasHeight,canvasWidth)
 		}
 		else{
 			ctx.strokeStyle = colors[index2];
-			ctx.lineWidth = 3;
+			ctx.lineWidth = 2.5;
 			index2++;
 		}
-	ctx.moveTo(50,50);
+	ctx.moveTo(50,150);
 	var x = 50;
 		for (var col = 1; col < data.getNumberOfColumns(); col++) 
 		{
@@ -353,30 +477,30 @@ function plotGraph(ctx,data,options,canvasHeight,canvasWidth)
 				var val = findDistinctColVal(data,row2,col-1);
 				if ((data.getDistinctValues(col-1).length-1) < 2)
 				{
-					ctx.moveTo(x,50);
+					ctx.moveTo(x,150);
 				}
 				else
 				{
-					ctx.moveTo(x,(canvasHeight)-(((val)/((data.getDistinctValues(col-1).length-1)/(canvasHeight-100)))+50));
+					ctx.moveTo(x,(canvasHeight-100)-(((val)/((data.getDistinctValues(col-1).length-1)/(canvasHeight-300)))+50));
 				}
 			}
 			else
 			{
 				if (step.max == 0)
 				{
-					ctx.moveTo(x,50);
+					ctx.moveTo(x,150);
 					if(col==1){
 						x_coords.push(x);
-						y_coords.push(50);
+						y_coords.push(150-70);
 					}
 				}
 				else
 				{
-					var temp_y =(canvasHeight)-(((data.getValue(row2, col-1))/((step.max)/(canvasHeight-100)))+50); 
+					var temp_y =(canvasHeight-100)-(((data.getValue(row2, col-1))/((step.max)/(canvasHeight-300)))+50);
 					ctx.moveTo(x,temp_y);
 					if(col==1){
 						x_coords.push(x);
-						y_coords.push(temp_y);
+						y_coords.push(temp_y-70);
 					}	
 				}
 			}
@@ -394,7 +518,7 @@ function plotGraph(ctx,data,options,canvasHeight,canvasWidth)
 				}
 				else
 				{
-					ctx.lineTo(x,(canvasHeight)-(((val)/((data.getDistinctValues(col).length-1)/(canvasHeight-100)))+50));				
+					ctx.lineTo(x,(canvasHeight-100)-(((val)/((data.getDistinctValues(col).length-1)/(canvasHeight-300)))+50));
 				}
 			}
 			else
@@ -403,14 +527,14 @@ function plotGraph(ctx,data,options,canvasHeight,canvasWidth)
 				{
 					ctx.lineTo(x,50);
 					x_coords.push(x);
-					y_coords.push(50);	
+					y_coords.push(50-70);
 				}
 				else
 				{
-					var temp_y = (canvasHeight)-(((data.getValue(row2, col))/((step.max)/(canvasHeight-100)))+50);
+					var temp_y = (canvasHeight-100)-(((data.getValue(row2, col))/((step.max)/(canvasHeight-300)))+50);
 					ctx.lineTo(x,temp_y);
 					x_coords.push(x);
-					y_coords.push(temp_y);	
+					y_coords.push(temp_y-70);
 				}
 			}
 			
@@ -434,28 +558,32 @@ findex = 0;
 		 	if (data.getColumnType(col) == "number"){
 				//console.log(x)
 				ctx.beginPath();
-				ctx.moveTo(x,(canvasHeight)-((upper/((step.max)/(canvasHeight-100)))+50));					
-				ctx.lineTo(x,(canvasHeight)-((lower/((step.max)/(canvasHeight-100)))+50));
-        			ctx.moveTo(x-10,(canvasHeight)-((upper/((step.max)/(canvasHeight-100)))+50));
-				ctx.lineTo(x+10,(canvasHeight)-((upper/((step.max)/(canvasHeight-100)))+50));
-				ctx.moveTo(x-10,(canvasHeight)-((lower/((step.max)/(canvasHeight-100)))+50));
-                                ctx.lineTo(x+10,(canvasHeight)-((lower/((step.max)/(canvasHeight-100)))+50));
+				ctx.moveTo(x,(canvasHeight-100)-((upper/((step.max)/(canvasHeight-300)))+50));
+				ctx.lineTo(x,(canvasHeight-100)-((lower/((step.max)/(canvasHeight-300)))+50));
+                ctx.moveTo(x-10,(canvasHeight-100)-((upper/((step.max)/(canvasHeight-300)))+50));
+				ctx.lineTo(x+10,(canvasHeight-100)-((upper/((step.max)/(canvasHeight-300)))+50));
+				ctx.moveTo(x-10,(canvasHeight-100)-((lower/((step.max)/(canvasHeight-300)))+50));
+                ctx.lineTo(x+10,(canvasHeight-100)-((lower/((step.max)/(canvasHeight-300)))+50));
 
 	 			ctx.closePath();
-                		ctx.stroke();
+                ctx.stroke();
 			}
 			findex++;
         	}
 	x= x + ((canvasWidth-50)/data.getNumberOfColumns());
 	}
 
-return(all_stderr);
+    
+var all = group_amounts.concat(all_stderr);
+var alln = group_names.concat(all);
+
+    return(alln);
 
 }
 
 
 '
-jsHeader2 <- sprintf(jsHeader2, groups, group_types, all_stderr)
+jsHeader2 <- sprintf(jsHeader2, groups, group_types, group_names, group_amounts, all_stderr, colors)
 jsHeader3 <-
 '
 function findDistinctColVal(data,row,col)
@@ -470,35 +598,44 @@ function findDistinctColVal(data,row,col)
 }
 function writeLabels(ctx,data,canvasHeight,canvasWidth) 
 {
-x = 30;
+x = 45;
 	for (var col = 0; col < data.getNumberOfColumns(); col++) 
 	{
 		
 		ctx.fillStyle = "#6E6E6E";
 		try
 		{
-			ctx.font = "10px Verdana";
-			ctx.fillText(data.getColumnLabel(col),x,canvasHeight-5);
+            ctx.save();
+            ctx.translate(x,canvasHeight-125);
+            ctx.rotate(+Math.PI/2);
+			ctx.font = "9px Verdana";
+			ctx.fillText(data.getColumnLabel(col),0,0);
+            ctx.restore();
+          
+            
 		}
 		catch(e)
 		{
 			ctx.mozTextStyle = "10px Verdana";
 			ctx.fillStyle = "#6E6E6E";
-			ctx.translate(x,canvasHeight-5);
+			ctx.translate(x,canvasHeight-105);
+            ctx.textAlign = "center";
 			ctx.mozDrawText(data.getColumnLabel(col));
-			ctx.translate(-x,-canvasHeight+5);
+			ctx.translate(-x,-canvasHeight+105);
 		}
+        
 		x= x + ((canvasWidth-50)/data.getNumberOfColumns());
 	}
 }
- 
+
+
 function writeTitle(ctx,options,canvasHeight,canvasWidth)
 {
 		ctx.fillStyle = "black";
 		try
 		{
 			ctx.font = "16px Verdana bold";
-			ctx.fillText(options.title,(canvasWidth/2)-((options.title.length)/2)-250,20);
+			ctx.fillText(options.title,(canvasWidth/2)-((options.title.length)/2)-250,90);
 		}
 		catch(e)
 		{
@@ -511,10 +648,11 @@ function writeTitle(ctx,options,canvasHeight,canvasWidth)
 		}
 }
 
+    
 // Main drawing logic.
 vizObj.ParallelC.prototype.draw = function(initial_data, data, options) {
 	
-	this.containerElement.innerHTML = \'<canvas id="graph_parallelC" style="position: absolute; left: 0; top: 0;"></canvas>\';
+	this.containerElement.innerHTML = \'<canvas id="graph_parallelC" style="position: absolute; left: 0; top: -70px;"></canvas>\';
 	//canvas properties
 	
 	if (options.width == undefined)
@@ -561,7 +699,7 @@ if (canvas.getContext)
 	
 	
 	//plotting data
-	all_stderr = plotGraph(ctx,data,options,canvasHeight,canvasWidth);
+	all = plotGraph(ctx,data,options,canvasHeight,canvasWidth);
 
 
 	//adding labels
@@ -570,12 +708,19 @@ if (canvas.getContext)
 	//adding chart title
 	writeTitle(ctx,options,canvasHeight,canvasWidth);
 	
-	createsvgs(initial_data, x_coords, y_coords, line_nu, group_nu, all_stderr);
+    
+    var group_names = all.slice(0,group_nu);
+    var group_amounts = all.slice(group_nu,2*group_nu);
+    var all_stderr = all.slice((2*group_nu), all.length );
+
+      
+      
+	createsvgs(initial_data, x_coords, y_coords, line_nu, group_nu, group_names, group_amounts, all_stderr);
 	
   }
   else
   {
-	this.containerElement.innerHTML = \'<span>This feature is not compatible with the brower you are currently using.</span>\';
+	this.containerElement.innerHTML = \'<span>This feature is not compatible with the browser you are currently using.</span>\';
   }
   
   
@@ -618,31 +763,44 @@ function drawVisualization(){
 var data = visovaData%s();
 var initial_data = visovaData%s();
 var vis = new vizObj.ParallelC(document.getElementById("%s"));
-vis.draw(initial_data, data, {width:window.innerWidth, height:window.innerHeight-100, title: \'VISOVA Coordinates Plot with Group Averages -- Column Ordering Method=%s\', lineColor:"#FE2E2E"});
+vis.draw(initial_data, data, {width:window.innerWidth, height:window.innerHeight+100, title: \'VISOVA Coordinates Plot with Group Averages -- Column Ordering Method=%s\', lineColor:"#FE2E2E"});
 
 }
 
-function createsvgs(initial_data, x_coords, ycoords, line_nu, group_nu, all_stderr){
+//CREATING A LEGEND
+function createsvgs(initial_data, x_coords, ycoords, line_nu, group_nu, group_names, group_amounts, all_stderr){
 
 $(document).ready(function () {
 
 s_index = x_coords.length -(line_nu * group_nu);
 e_index = x_coords.length;
 
-ini_HTML = "<svg id=\'bbb\' style= \'position: absolute; left: 0; top:0 ; fill:gray;stroke:black;stroke-width:4;opacity:0.5\'><rect x=\'20\' y=\'1\' rx=\'10\' ry=\'10\' width=\'1190\' height=\'30\'/></svg><svg id=\'aaa\' style= \'position: absolute; left: 0; top:0 ; fill:gray;stroke:black;stroke-width:2;opacity:0.4\'><rect x=\'20\' y=\'650\' rx=\'10\' ry=\'10\' width=\'1190\' height=\'30\'/></svg>"; 
 
-var dist = 1190/group_nu;
-l_add = "<svg style= \'position: absolute; left: 0; top:0;\'>";
-var dist2 =50;
-for(var indexl=0; indexl<group_nu; indexl++){
-	addll = "<rect x=" + dist2 + " y=\'658\' width=\'12\' height=\'12\'style=\'fill:"+colors[indexl]+";stroke:black;stroke-width:1;stroke-opacity:0.9\'/><text x="+(dist2+20)+" y=\'669\' fill=\'black\'>GROUP-"+(indexl+1)+"</text>";
-	l_add = l_add + addll;
-	dist2 = dist2+dist;
-}
+                  if(group_nu<7){
+                  var sbst = group_nu * 200;
+                  }else{
+                  var sbst = group_nu * 125;
+                  }
+                  var dist = (window.innerWidth-sbst)/2;
 
-ini_HTML = ini_HTML + l_add + "</svg>";
+                  l_add = "<svg style= \'position: absolute; left: 0; top:0;\'>";
+                  for(var indexl=0; indexl<group_nu; indexl++){
+                        addll = "<rect x=" + dist + " y=\'40\' width=\'12\' height=\'12\'style=\'fill:"+colors[indexl]+";stroke:black;stroke-width:1;stroke-opacity:0.9\'/><text x="+(dist+17)+" y=\'51\' fill=\'black\'>"+group_names[indexl]+" ("+group_amounts[indexl]+")"+"</text>";
+                  l_add = l_add + addll;
+                  
+                  if(group_nu<7){
+                  dist += 200;}
+                  else{
+                  dist += 125;
+                  }
+                  }
 
-initialHTML = "<svg id=\'aaa\' style= \'position: absolute; left: 0; top: 0;\'><defs><filter id=\'f1\' x=\'0\' y=\'0\'><feGaussianBlur in=\'SourceGraphic\' stdDeviation=\'15\' /></filter><style type=\'text/css\'><![CDATA[";
+
+                 
+ini_HTML = l_add + "</svg>";
+
+                  
+initialHTML = "<svg id=\'bbb\' style= \'position: absolute; left: 0; top: 0;\'><defs><filter id=\'f1\' x=\'0\' y=\'0\'><feGaussianBlur in=\'SourceGraphic\' stdDeviation=\'15\' /></filter><style type=\'text/css\'><![CDATA[";
 
 add="";
 
@@ -657,8 +815,7 @@ var tchs = new Array();
 for(var index0 = 0; index0<group_nu; index0++ ){
 	tch = "touchable"+index0; 
 	tchs.push(tch);
-	add0 = "."+tch+"{ fill: transparent; stroke: transparent; stroke-width: 0.05cm; }."+tch+":hover { fill:" + colors[index0] +"; stroke:white; stroke-width: 0.04cm; }"
-
+	add0 = "."+tch+"{ fill: transparent; stroke: transparent; stroke-width: 0.05cm; }."+tch+":hover { fill:" + colors[index0] +"; stroke:white; stroke-width: 0.04cm; }";
 	if(add==""){
 		add = add0;
 	}else{
@@ -701,11 +858,12 @@ for(var j=0; j<group_nu; j++){
 var innertext = new Array();
 g_l = 0;
 for (var row = initial_data.getNumberOfRows()-group_nu ; row < initial_data.getNumberOfRows() ; row++){
-	g_l++;
+
 	for(var col = 0; col<line_nu ; col++){
-		temp = "Group - "+g_l+"<br/>"+ initial_data.getColumnLabel(col) +" Mean: " +Math.round(initial_data.getValue(row,col)*100)/100;		 
+		temp = group_names[g_l]+"<br/>"+ initial_data.getColumnLabel(col) +" Mean: " +Math.round(initial_data.getValue(row,col)*100)/100;
 		innertext.push(temp);	
 	}
+    g_l++;
 }
 
 //CREATING TOOLTIPS
@@ -934,9 +1092,11 @@ checkSquareCurlBracketOps <- function(char){
   ifelse(first %in% c("{","[") & last %in% c("}", "]"), TRUE, FALSE)
 }
 
+         
+         
 visovaHtmlWrapper <- function(title, dataName, chartid, type){
   
-  htmlHeader <- '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
+htmlHeader <- '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
@@ -962,15 +1122,20 @@ body {
 </head>
 <body>
 '
-  htmlHeader <- sprintf(htmlHeader,chartid) 
-  
-  htmlFooter <- '
+         
+htmlHeader <- sprintf(htmlHeader,chartid)
+
+         
+         
+htmlFooter <- '
 </body>
 <!-- htmlFooter -->
 
 <span>
 <br/><br/><br/>
 <br/><br/><br/>
+<br/><br/><br/>
+<br/><br/><br/>
 // VISOVA package version 1.0<br/>
 //  %s &#8226;
 </span>
@@ -978,14 +1143,11 @@ body {
 </html>
 '
    
-  htmlFooter <- sprintf(htmlFooter, R.Version()$version.string)  
-  htmlCaption <- ""
-#  htmlCaption <- sprintf('<div><span>Data: %s &#8226; VISOVA Chart ID: <a href="Chart_%s.html">%s</a></span><br />' ,
-#                         dataName, chartid, chartid)
-  
+  htmlFooter <- sprintf(htmlFooter, R.Version()$version.string)
+         
+         
   return(list(htmlHeader=htmlHeader,
-              htmlFooter=htmlFooter,
-              htmlCaption=htmlCaption
+              htmlFooter=htmlFooter
   ))
 }
 
